import os.path
parent = (os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir)))


def style(name='default'):
    style = {'default' : 'bd=0;bg=#ffffff;',
             'default2' : 'bd=0;bg=#7d7d7d;',
             'default4' : 'path='+parent+'/img/rv.png;',
             'default5' : 'path='+parent+'/img/wv.png;',
             'default6' : 'path='+parent+'/img/bb.png;',
             'Bfc' : 'bg=#f7f7f7;bd=0;',
             'lkst' : 'path='+parent+'/img/linkstat.png;circular=True;',
             'lksh' : 'path='+parent+'/img/linksearch.png;circular=True;',
             'lksv' : 'path='+parent+'/img/linksave.png;circular=True;',
             'lked' : 'path='+parent+'/img/linked.png;circular=True;',
             'lkedyn' : 'path='+parent+'/img/linkdyn.png;circular=True;',
             'lkdl' : 'path='+parent+'/img/linkdel.png;circular=True;',
             'kwsv' : 'path='+parent+'/img/kwsv.png;circular=True;',
             'pin' : 'path='+parent+'/img/pin.png;circular=True;',
             'domains' : 'path='+parent+'/img/domains.png;circular=True;',
             'keywords' : 'path='+parent+'/img/keywords.png;circular=True;',
             'history' : 'path='+parent+'/img/history.png;circular=True;',
             'media' : 'path='+parent+'/img/media.png;circular=True;',
             'folders' : 'path='+parent+'/img/folders.png;circular=True;',
             'Tbd' : 'bd=0;bg=#ffffff;fg=#0000cd;highlightthickness=2;highlightcolor=#0000cd;',
             'folder' : 'path='+parent+'/img/folder.jpg;',
             'Xbg' : 'path='+parent+'/img/xbg.png;',
             'Wbg' : 'bd=0;bg=#ffffff;',
             'Bbg' : 'bd=0;bg=#0000cd;',
             'butCnv' : 'image=;width=7;height=2;fg=#7d7d7d;',
             'navClick' : 'bg=#0000cd;highlightcolor=#0000cd;',
             'DlogoR' : 'path='+parent+'/img/logo.png;',
             'DlogoR2' : 'path='+parent+'/img/logo2.png;',
             'Dtext' : 'text=Dosie;font=Helvetica 11 bold;image=;width=5;height=2;',
             'blueBr' : 'path='+parent+'/img/blueButton.png;',
             'nBott' : 'path='+parent+'/img/bh.png;',
             'topIndL' : 'path='+parent+'/img/lt.png;',
             'topIndLT' : 'image=;width=30;height=2;text=Start new search;anchor=w;fg=#7d7d7d;',
             'google' : 'path='+parent+'/img/google.png;circular=True;',
             'Dbg' : 'bd=0;bg=#f0f0f0;padx=1;pady=1;',
             'bgb' : 'background=#0000cd;rad=58;',
             'bgw' : 'background=#ffffff;rad=58;',
             'ctB' : 'bg=#000080;',
             'ctrlCnrOP' : 'path='+parent+'/img/cop.png;',
             'settings1' : 'path='+parent+'/img/set1.png;circular=True;',
             'settings2' : 'path='+parent+'/img/set2.png;circular=True;',
             'settings3' : 'path='+parent+'/img/set3.png;circular=True;',
             'relev' : 'path='+parent+'/img/pers.png;',
             'load' : 'path='+parent+'/img/load.png;circular=True;',
             'fim' : 'path='+parent+'/img/domainICO/Icon.png;circular=True;',
             'pdf' : 'path='+parent+'/img/pdf.png;',
             'mp4' : 'path='+parent+'/img/mp4.png;',
             'jpg' : 'path='+parent+'/img/jpg.png;',
             'png' : 'path='+parent+'/img/png.png;',
             'mp3' : 'path='+parent+'/img/mp3.png;',
             'wav' : 'path='+parent+'/img/wav.png;',
             'txt' : 'path='+parent+'/img/txt.png;',
             }
    
    return style[name]



import urllib.parse
import urllib.request
import os
import requests
import sys
import json
import logging

def my_handler(exc_type, exc_value, exc_traceback):
    ff = 'error.log'
    if 'SystemExit'.lower() in str(exc_type).lower():
        return
    logging.basicConfig(filename=ff,level=logging.DEBUG)
    logging.error("Uncaught exception", exc_info=(exc_type, exc_value, exc_traceback))
    logging.warning('And this, too')
    logging.debug('This message should go to the log file')
    logging.info('So should this')
    with open(ff,'a+') as ff:
        ff.write('\nEND-------------------------------\n-------------------------------\n\n')

sys.excepthook = my_handler

configPath = os.path.dirname(__file__)


file = sys.argv[1]
sys.argv[2] = sys.argv[2].replace('\'','"')
param = json.loads(sys.argv[2])




url = 'https://eliezerodjao.com/Dosie/stats.php'
the_page = False
if file == True or file == 'True':
    if os.path.getsize(param['file']) > 0:
        with open(param['file'], 'rb') as f:
            try:
                the_page = requests.post(url, data=param, files={param['file']: f})
            except:
                the_page = False
        if the_page:
            with open(param['file'],'w+') as df:
                df.write('')
else:
    values = param
    data = urllib.parse.urlencode(values)
    data = data.encode('ascii')
    req = urllib.request.Request(url, data)
    try:
        with urllib.request.urlopen(req) as response:
            the_page = str(response.read())
    except:
        the_page = False




import setuptools



with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="Dosie",
    version="0.0.3",
    author="Eliezer Odjao",
    author_email="eliezerodjaoofficial@gmail.com",
    description="A search engine that makes knowledge a resource, and creates liberation with information sharing",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://eliezerodjao.com/desktop/portfolio.php?sent=dosie",
    license="Proprietary",
    packages=setuptools.find_packages(),
    include_package_data=True,
    keywords='search searchEngine information web internet data',
    install_requires=['Synx','Pillow','requests'],
    python_requires='~=3.3',
    classifiers=[
        "Environment :: Win32 (MS Windows)",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.4",
        "License :: Other/Proprietary License",
        "Operating System :: Microsoft :: Windows",
        "Development Status :: 3 - Alpha",
        "Intended Audience :: End Users/Desktop",
        "Natural Language :: English",
        "Topic :: Communications",
        "Topic :: Education",
        "Topic :: Internet",
        "Topic :: Internet :: WWW/HTTP :: Browsers",
        "Topic :: Internet :: WWW/HTTP :: Indexing/Search"
    ],
    project_urls={
    'Documentation': 'https://eliezerodjao.com/docs/Dosie_User0v0v3_Documentation.docx',
    'Source': 'https://eliezerodjao.com/desktop/portfolio.php?sent=dosie'
    }
)



import re

class trackSectionPosition():
    def __init__(self):
        pass
    parentName = ''
    parentIndicate = 0

    def reset(self):
        self.parentName = ''
        self.parentIndicate = 0
    
    indicateParent = ['A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z'];

    def nameParent(self):
        if(self.parentIndicate == 26):
            self.parentIndicate = 0
            self.parentName += self.indicateParent[self.parentIndicate]
        else:
            self.parentName = self.parentName[0:-1] + self.indicateParent[self.parentIndicate]
        self.parentIndicate += 1

class elementBody(trackSectionPosition):
    opened = '<div '
    opened2 = '<div>'
    closed = '</div>'
    Eopen = ''
    Eclose = ''
    Dopen = 0
    whoOpened = 0
    openIndicate = 0
    
    whatString = ""
    ifFound = False
    querSize = 0
    pointDist = 0
    PartIndex = 0
    u_Query = ''
    full_find = []
    YesParts = []
    confYesParts = []
    sectionNameing = []

    def __init__(self,userQuery):
        trackSectionPosition.__init__(self)
        self.querSize = len(userQuery) * 4
        self.u_Query = userQuery

    def initQuery(self,userQuery):
        self.querSize = len(userQuery) * 4
        self.u_Query = userQuery

    def reset(self):
        self.Eopen = ''
        self.Eclose = ''
        self.Dopen = 0
        self.whoOpened = 0
        self.openIndicate = 0
    
        self.whatString = ""
        self.ifFound = False
        self.querSize = 0
        self.pointDist = 0
        self.PartIndex = 0
        self.u_Query = ''
        self.full_find = []
        self.YesParts = []
        self.confYesParts = []
        self.sectionNameing = []

    def setEopen(self,a):
        if(self.ifFound == True):
            self.whatString += a
        self.Eopen += a
        lt = len(self.Eopen)
        if(self.opened[0:lt] == self.Eopen):
            self.setOpen()
        elif(self.opened2[0:lt] == self.Eopen):
            self.setOpen()
        else:
            self.Eopen = ''

    def remove_tags(self,text):
        TAG_RE = re.compile(r'<[^>]+>')
        return TAG_RE.sub('', text)

    def set_in(self,clean,tag,img = False):
        self.pointDist += 1
        yhParts = self.YesParts
        said = self.u_Query.split(' ')
        for i in range(len(said)):
            if img == False:
                if tag == 'a':
                    if (' '+clean+' ').lower().find(said[i].lower()) > -1 and '/search?client=' not in clean and 'webcache.googleusercontent' not in clean and 'support.google' not in clean and '/search?q=' not in clean and 'www.google.com/intl' not in clean:
                        if clean not in self.confYesParts:
                            carr = ['&nbsp;','&lt;','&gt;','&amp;','&quot;','&apos;','&cent;','&pound;','&yen;','&euro;','&copy;','&reg;','\\n','\\t','\\r','\\b']
                            for char in carr:
                                clean = clean.replace(char,'')
                            yhParts.append([tag,self.pointDist,clean])
                            self.confYesParts.append(clean)
                else:
                    if (' '+clean+' ').lower().find(' '+said[i].lower()+' ') > -1 and '/search?client=' not in clean and 'webcache.googleusercontent' not in clean and 'support.google' not in clean and '/search?q=' not in clean and 'www.google.com/intl' not in clean:
                        if clean not in self.confYesParts:
                            carr = ['&nbsp;','&lt;','&gt;','&amp;','&quot;','&apos;','&cent;','&pound;','&yen;','&euro;','&copy;','&reg;','\\n','\\t','\\r','\\b']
                            for char in carr:
                                clean = clean.replace(char,'')
                            yhParts.append([tag,self.pointDist,clean])
                            self.confYesParts.append(clean)
            else:
                if (' '+clean+' ').lower().find(said[i].lower()) > -1 and '/search?client=' not in clean and 'webcache.googleusercontent' not in clean and 'support.google' not in clean and '/search?q=' not in clean and 'www.google.com/intl' not in clean:
                    if clean not in self.confYesParts:
                        carr = ['&nbsp;','&lt;','&gt;','&amp;','&quot;','&apos;','&cent;','&pound;','&yen;','&euro;','&copy;','&reg;','\\n','\\t','\\r','\\b']
                        for char in carr:
                            clean = clean.replace(char,'')
                        yhParts.append([tag,self.pointDist,clean])
                        self.confYesParts.append(clean)

    def getClean(self,st,tag,pos):
        see = '<'+tag+' '
        seeT = '<'+tag+'>'
        tfg = False
        if(st.find(see) > -1):
            if(st.find(seeT) > -1):
                if(st.find(seeT) < st.find(see)):
                    first = st.find(seeT)
                    tgg = seeT
                else:
                    first = st.find(see)
                    tgg = see
                    tfg = True
            else:
                first = st.find(see)
                tgg = see
                tfg = True
        else:
            first = st.find(seeT)
            tgg = seeT

        ele = st[0:pos]
        Href = ''
        if tag == 'a':
            src = re.findall('href="(.+?)"',ele)
            if src:
                Href = src[0]+' ~||~ '
        before = ele[first + len(tgg):]
        if(tfg == True):
            before = '<div'+before+'</div>'
        clean = self.remove_tags(before)
        #if(indx < 3):
        #    itt = 0
        #else:
        #    itt = indx - 2
        self.set_in(Href+clean,tag)
        return st[pos + len('</'+tag+'>'):]

    def elements(self,st):
        while len(st) > 0:
            h1 = st.find('</h1>')
            if(h1 < 0):
                h1 = len(st)
            h2 = st.find('</h2>')
            if(h2 < 0):
                h2 = len(st)
            h3 = st.find('</h3>')
            if(h3 < 0):
                h3 = len(st)
            p = st.find('</p>')
            if(p < 0):
                p = len(st)
            a = st.find('</a>')
            if(a < 0):
                a = len(st)
            td = st.find('</td>')
            if(td < 0):
                td = len(st)
            li = st.find('</li>')
            if(li < 0):
                li = len(st)
            if(h1 == len(st) and h2 == len(st) and h3 == len(st) and p == len(st) and a == len(st) and td == len(st) and li == len(st)):
                if(st.find('<script ') > -1):
                    st = ''
                else:
                    var_Headdings1 = re.findall('<img (.+?)>',st)
                    for j in range(len(var_Headdings1)):
                        st = st.replace('<img '+var_Headdings1[j]+'>','')
                        src = re.findall('src="(.+?)"',var_Headdings1[j])
                        if src:
                            self.set_in(src[0],'img',True)
                    try1 = '<div '+st+'</div>'
                    try2 = '<div>'+st+'</div>'
                    st1 = self.remove_tags(try1)
                    st2 = self.remove_tags(try2)
                    if(len(st1) > 0):
                        st = st1
                    else:
                        st = st2
                self.set_in(st,'plane')
                st = '';
            else:
                if(st.find('<script ') > -1):
                    st = ''
                else:
                    mann = ['h1','h2','h3','p','a','td','li']
                    mnn2 = [h1,h2,h3,p,a,td,li]
                    max_value = min(mnn2)
                    max_index = mnn2.index(max_value)
                    st = self.getClean(st,mann[max_index],max_value)

    def updateSetContent(self):
        if((self.whatString).startswith('<div>') or (self.whatString).startswith('<div ')):
            self.whatString = self.whatString[len('<div>'):]
        self.whatString = self.whatString[0:-5]
        self.whatString = (self.whatString).strip()
        if((self.whatString).endswith('<')):
            self.whatString = self.whatString[0:-1]
        self.whatString = (self.whatString).strip()
        if(len(self.whatString) > 0 and self.whatString != '>'):
            pass
        self.elements(self.whatString)
        self.whatString = ""

    def setOpen(self):
        if(self.Eopen == '<div ' or self.Eopen == '<div>'):
            self.updateSetContent()
            self.ifFound = True
            self.whoOpened += 1
            self.openIndicate += 1
            self.Dopen += 1
            self.Eopen = ''

    def setEclose(self,a):
        self.Eclose += a
        lt = len(self.Eclose)
        if(self.closed[0:lt] == self.Eclose):
            self.setClose()
        else:
            self.Eclose = ''

    def setClose(self):
        if(self.Eclose == '</div>'):
            self.updateSetContent()
            self.ifFound = False
            self.openIndicate = 0
            self.Dopen -= 1
            self.Eclose = ''
            if(self.Dopen == 0):
                var_ctn = False
                for i in range(len(self.YesParts)):
                    if self.YesParts[i]:
                        self.full_find.append(self.YesParts)
                        var_ctn = True
                        self.PartIndex += 1
                        break
                if(var_ctn == True):
                    self.sectionNameing.append([True,self.parentName,(self.PartIndex - 1)])
                else:
                    self.sectionNameing.append([False,self.parentName,0])
                self.YesParts = []
                self.confYesParts = []
                self.nameParent()

class Into_Perspective():
    plaque = []
    passStr = ''
    spacNum = 0

    def reset(self):
        self.passStr = ''
        self.plaque = []
        self.spacNum = 0
    
    def Tabs(self,arr):
        self.reset()
        for i in range(len(arr)):
            if i == 0:
                spacNum = arr[i][1]
            if arr[i][1] - spacNum < 4:
                tagType = arr[i][0]
                if tagType != 'space':
                    self.passStr += '<'+tagType+'> '+arr[i][2]+' </'+tagType+'><-||DOSIE||->\n'
                else:
                    self.passStr += '<'+tagType+'> '+arr[i][2]+' </'+tagType+'><-||DOSIE||->\n'
            else:
                self.plaque.append(self.passStr)
                self.passStr = ''
                tagType = arr[i][0]
                if tagType != 'space':
                    self.passStr += '<'+tagType+'> '+arr[i][2]+' </'+tagType+'><-||DOSIE||->\n'
                else:
                    self.passStr += '<'+tagType+'> '+arr[i][2]+' </'+tagType+'><-||DOSIE||->\n'
                spacNum = arr[i][1]
        return self.plaque
